==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/Slowo.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class Slowo extends GenericDPSObject {
    /**
     * SLOWO.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * SLOWO.SLOWNIK_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long slownikId;

    /**
     * SLOWO.KOD
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String kod;

    /**
     * SLOWO.WART_STRING
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String wartString;

    /**
     * SLOWO.WART_INT
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Integer wartInt;

    /**
     * SLOWO.WAZNOSC_OD
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date waznoscOd;

    /**
     * SLOWO.WAZNOSC_DO
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date waznoscDo;

    /**
     * SLOWO.KOLEJNOSC
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Integer kolejnosc;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return SLOWO.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * SLOWO.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return SLOWO.SLOWNIK_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getSlownikId() {
        return slownikId;
    }

    /**
     * SLOWO.SLOWNIK_ID
     *
     * @param slownikId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setSlownikId(Long slownikId) {
        this.slownikId = slownikId;
    }

    /**
     * @return SLOWO.KOD
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getKod() {
        return kod;
    }

    /**
     * SLOWO.KOD
     *
     * @param kod
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKod(String kod) {
        this.kod = kod == null ? null : kod.trim();
    }

    /**
     * @return SLOWO.WART_STRING
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getWartString() {
        return wartString;
    }

    /**
     * SLOWO.WART_STRING
     *
     * @param wartString
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setWartString(String wartString) {
        this.wartString = wartString == null ? null : wartString.trim();
    }

    /**
     * @return SLOWO.WART_INT
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Integer getWartInt() {
        return wartInt;
    }

    /**
     * SLOWO.WART_INT
     *
     * @param wartInt
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setWartInt(Integer wartInt) {
        this.wartInt = wartInt;
    }

    /**
     * @return SLOWO.WAZNOSC_OD
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getWaznoscOd() {
        return waznoscOd;
    }

    /**
     * SLOWO.WAZNOSC_OD
     *
     * @param waznoscOd
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setWaznoscOd(Date waznoscOd) {
        this.waznoscOd = waznoscOd;
    }

    /**
     * @return SLOWO.WAZNOSC_DO
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getWaznoscDo() {
        return waznoscDo;
    }

    /**
     * SLOWO.WAZNOSC_DO
     *
     * @param waznoscDo
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setWaznoscDo(Date waznoscDo) {
        this.waznoscDo = waznoscDo;
    }

    /**
     * @return SLOWO.KOLEJNOSC
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Integer getKolejnosc() {
        return kolejnosc;
    }

    /**
     * SLOWO.KOLEJNOSC
     *
     * @param kolejnosc
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKolejnosc(Integer kolejnosc) {
        this.kolejnosc = kolejnosc;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        Slowo other = (Slowo) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getSlownikId() == null ? other.getSlownikId() == null : this.getSlownikId().equals(other.getSlownikId()))
            && (this.getKod() == null ? other.getKod() == null : this.getKod().equals(other.getKod()))
            && (this.getWartString() == null ? other.getWartString() == null : this.getWartString().equals(other.getWartString()))
            && (this.getWartInt() == null ? other.getWartInt() == null : this.getWartInt().equals(other.getWartInt()))
            && (this.getWaznoscOd() == null ? other.getWaznoscOd() == null : this.getWaznoscOd().equals(other.getWaznoscOd()))
            && (this.getWaznoscDo() == null ? other.getWaznoscDo() == null : this.getWaznoscDo().equals(other.getWaznoscDo()))
            && (this.getKolejnosc() == null ? other.getKolejnosc() == null : this.getKolejnosc().equals(other.getKolejnosc()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getSlownikId() == null) ? 0 : getSlownikId().hashCode());
        result = prime * result + ((getKod() == null) ? 0 : getKod().hashCode());
        result = prime * result + ((getWartString() == null) ? 0 : getWartString().hashCode());
        result = prime * result + ((getWartInt() == null) ? 0 : getWartInt().hashCode());
        result = prime * result + ((getWaznoscOd() == null) ? 0 : getWaznoscOd().hashCode());
        result = prime * result + ((getWaznoscDo() == null) ? 0 : getWaznoscDo().hashCode());
        result = prime * result + ((getKolejnosc() == null) ? 0 : getKolejnosc().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", slownikId=").append(slownikId);
        sb.append(", kod=").append(kod);
        sb.append(", wartString=").append(wartString);
        sb.append(", wartInt=").append(wartInt);
        sb.append(", waznoscOd=").append(waznoscOd);
        sb.append(", waznoscDo=").append(waznoscDo);
        sb.append(", kolejnosc=").append(kolejnosc);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/Slowo.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class Slowo extends GenericDPSObject {
    /**
     * SLOWO.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * SLOWO.SLOWNIK_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long slownikId;

    /**
     * SLOWO.KOD
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String kod;

    /**
     * SLOWO.WART_STRING
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String wartString;

    /**
     * SLOWO.WART_INT
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Integer wartInt;

    /**
     * SLOWO.WAZNOSC_OD
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date waznoscOd;

    /**
     * SLOWO.WAZNOSC_DO
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date waznoscDo;

    /**
     * SLOWO.KOLEJNOSC
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Integer kolejnosc;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return SLOWO.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * SLOWO.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return SLOWO.SLOWNIK_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getSlownikId() {
        return slownikId;
    }

    /**
     * SLOWO.SLOWNIK_ID
     *
     * @param slownikId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setSlownikId(Long slownikId) {
        this.slownikId = slownikId;
    }

    /**
     * @return SLOWO.KOD
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getKod() {
        return kod;
    }

    /**
     * SLOWO.KOD
     *
     * @param kod
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKod(String kod) {
        this.kod = kod == null ? null : kod.trim();
    }

    /**
     * @return SLOWO.WART_STRING
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getWartString() {
        return wartString;
    }

    /**
     * SLOWO.WART_STRING
     *
     * @param wartString
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setWartString(String wartString) {
        this.wartString = wartString == null ? null : wartString.trim();
    }

    /**
     * @return SLOWO.WART_INT
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Integer getWartInt() {
        return wartInt;
    }

    /**
     * SLOWO.WART_INT
     *
     * @param wartInt
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setWartInt(Integer wartInt) {
        this.wartInt = wartInt;
    }

    /**
     * @return SLOWO.WAZNOSC_OD
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getWaznoscOd() {
        return waznoscOd;
    }

    /**
     * SLOWO.WAZNOSC_OD
     *
     * @param waznoscOd
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setWaznoscOd(Date waznoscOd) {
        this.waznoscOd = waznoscOd;
    }

    /**
     * @return SLOWO.WAZNOSC_DO
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getWaznoscDo() {
        return waznoscDo;
    }

    /**
     * SLOWO.WAZNOSC_DO
     *
     * @param waznoscDo
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setWaznoscDo(Date waznoscDo) {
        this.waznoscDo = waznoscDo;
    }

    /**
     * @return SLOWO.KOLEJNOSC
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Integer getKolejnosc() {
        return kolejnosc;
    }

    /**
     * SLOWO.KOLEJNOSC
     *
     * @param kolejnosc
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKolejnosc(Integer kolejnosc) {
        this.kolejnosc = kolejnosc;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        Slowo other = (Slowo) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getSlownikId() == null ? other.getSlownikId() == null : this.getSlownikId().equals(other.getSlownikId()))
            && (this.getKod() == null ? other.getKod() == null : this.getKod().equals(other.getKod()))
            && (this.getWartString() == null ? other.getWartString() == null : this.getWartString().equals(other.getWartString()))
            && (this.getWartInt() == null ? other.getWartInt() == null : this.getWartInt().equals(other.getWartInt()))
            && (this.getWaznoscOd() == null ? other.getWaznoscOd() == null : this.getWaznoscOd().equals(other.getWaznoscOd()))
            && (this.getWaznoscDo() == null ? other.getWaznoscDo() == null : this.getWaznoscDo().equals(other.getWaznoscDo()))
            && (this.getKolejnosc() == null ? other.getKolejnosc() == null : this.getKolejnosc().equals(other.getKolejnosc()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getSlownikId() == null) ? 0 : getSlownikId().hashCode());
        result = prime * result + ((getKod() == null) ? 0 : getKod().hashCode());
        result = prime * result + ((getWartString() == null) ? 0 : getWartString().hashCode());
        result = prime * result + ((getWartInt() == null) ? 0 : getWartInt().hashCode());
        result = prime * result + ((getWaznoscOd() == null) ? 0 : getWaznoscOd().hashCode());
        result = prime * result + ((getWaznoscDo() == null) ? 0 : getWaznoscDo().hashCode());
        result = prime * result + ((getKolejnosc() == null) ? 0 : getKolejnosc().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", slownikId=").append(slownikId);
        sb.append(", kod=").append(kod);
        sb.append(", wartString=").append(wartString);
        sb.append(", wartInt=").append(wartInt);
        sb.append(", waznoscOd=").append(waznoscOd);
        sb.append(", waznoscDo=").append(waznoscDo);
        sb.append(", kolejnosc=").append(kolejnosc);
        sb.append("]");
        return sb.toString();
    }
}
